@@ -461,7 +461,10 @@ class SQLObjectStore(ObjectStore):
         This is a hook for subclasses that wish to influence this event.
         Invoked by executeSQL().
         """
-        cur.execute(sql, clausesArgs)
+        if clausesArgs:
+            cur.execute(sql, clausesArgs)
+        else:
+            cur.execute(sql)
 
     def executeSQLTransaction(self, transaction, connection=None, commit=True):
         """Execute the given sequence of SQL statements and commit as transaction."""
@@ -716,7 +719,7 @@ class SQLObjectStore(ObjectStore):
     def dumpObjectStore(self, out=None, progress=False):
         if out is None:
             out = sys.stdout
-        for klass in self.model().klasses().values():
+        for klass in sorted(self.model().klasses().values(), key=lambda k: k.name()):
             if progress:
                 sys.stderr.write(".")
             out.write('%s objects\n' % (klass.name()))
