@@ -10,7 +10,6 @@ class TaskHandler(object):
     the TaskHandler has all the knowledge about the periodicity of the task.
     Instances of this class are managed by the Scheduler in the scheduled,
     running and onDemand dictionaries.
-
     """
 
 
@@ -29,7 +28,7 @@ class TaskHandler(object):
         self._reregister = True
         self._rerun = False
         self._period = abs(period)
-
+        self._isOnDemand = False
 
     ## Scheduling ##
 
@@ -54,7 +53,6 @@ class TaskHandler(object):
 
         Increments the startTime and returns true if this is
         a periodically executed task.
-
         """
         if self._period == 0 or not self._reregister:
             return False
@@ -87,20 +85,21 @@ class TaskHandler(object):
 
         This method lets the Scheduler check to see whether this task should be
         re-run when it terminates.
-
         """
         return self._rerun
 
     def isOnDemand(self):
         """Return True if this task is not scheduled for periodic execution."""
-        return self._period == 0
+        return self._isOnDemand
+
+    def setOnDemand(self, onDemand=True):
+        self._isOnDemand = bool(onDemand)
 
     def runOnCompletion(self):
         """Request that this task be re-run after its current completion.
 
         Intended for on-demand tasks that are requested by the Scheduler while
         they are already running.
-
         """
         self._rerun = True
 
@@ -108,7 +107,6 @@ class TaskHandler(object):
         """Request that this task not be kept after its current completion.
 
         Used to remove a task from the scheduler.
-
         """
         self._reregister = False
         self._rerun = False
