@@ -8,10 +8,11 @@ the changes take effect.
 An example, URL:
 
     http://127.0.0.1/OneShot.cgi/MyPage
-
 """
 
-import sys, os, time
+import sys
+import os
+import time
 try:
     from cStringIO import StringIO
 except ImportError:
@@ -28,14 +29,14 @@ class OneShotAdapter(Adapter):
         config = Adapter.defaultConfig(self)
         config.update(
             ShowConsole = False,
-            ConsoleWidth = 80, # use 0 to turn off
+            ConsoleWidth = 80,  # use 0 to turn off
             ConsoleHangingIndent = 4,
         )
         return config
 
     def run(self):
 
-        timestamp = time.time() # start time
+        timestamp = time.time()  # start time
 
         # to capture the console output of the application
         stdout, sys.stdout = sys.stdout, StringIO()
