@@ -2,7 +2,6 @@
 
 import time
 import threading
-from operator import itemgetter
 
 from MiscUtils import NoDefault
 
@@ -61,7 +60,7 @@ class SessionDynamicStore(SessionStore):
         # all code that moves sessions between the file and memory stores, and
         # is also used to protect code that searches in the file store for a
         # session. Using the lock in this way avoids a bug that used to be in
-        #this code, where a session was temporarily neither in the file store
+        # this code, where a session was temporarily neither in the file store
         # nor in the memory store while it was being moved from file to memory.
         self._lock = threading.RLock()
 
@@ -281,12 +280,6 @@ class SessionDynamicStore(SessionStore):
                 len(self._memoryStore), len(self._fileStore))
 
     def memoryKeysInAccessTimeOrder(self):
-        """Return memory store's keys in ascending order of last access time."""
-        accessTimeAndKeys = []
-        for key in self._memoryStore:
-            try:
-                accessTimeAndKeys.append(
-                    (self._memoryStore[key].lastAccessTime(), key))
-            except KeyError:
-                pass
-        return map(itemgetter(1), sorted(accessTimeAndKeys))
+        """Fetch memory store's keys in ascending order of last access time."""
+        return [session.identifier() for session in sorted(
+            self._memoryStore.values(), key=lambda v: v.lastAccessTime())]
