@@ -144,7 +144,7 @@ class ContextParser(URLParser):
 
     ## Context handling ##
 
-    def resolveDefaultContext(self, name, dest):
+    def resolveDefaultContext(self, dest):
         """Find default context.
 
         Figure out if the default context refers to an existing context,
@@ -154,22 +154,18 @@ class ContextParser(URLParser):
         or 'default' if the default context is unique.
         """
         contexts = self._contexts
-        contextDirs = {}
-        # make a list of existing context paths
-        for name, path in contexts.items():
-            if name != 'default':
-                contextDirs[self.absContextPath(path)] = name
         if dest in contexts:
             # The default context refers to another context,
             # not a unique context.  Return the name of that context.
             return dest
-        elif self.absContextPath(dest) in contextDirs:
-            # The default context has the same directory
-            # as another context, so it's still not unique
-            return contextDirs[self.absContextPath(dest)]
-        else:
-            # The default context has no other name
-            return 'default'
+        destPath = self.absContextPath(dest)
+        for name, path in contexts.items():
+            if name != 'default' and self.absContextPath(path) == destPath:
+                # The default context has the same directory
+                # as another context, so it's still not unique
+                return name
+        # The default context has no other name
+        return 'default'
 
     def addContext(self, name, path):
         """Add a context to the system.
@@ -179,7 +175,7 @@ class ContextParser(URLParser):
         the context name.
         """
         if name == 'default':
-            dest = self.resolveDefaultContext(name, path)
+            dest = self.resolveDefaultContext(path)
             self._defaultContext = dest
             if dest != 'default':
                 # in this case default refers to an existing context, so
@@ -316,7 +312,7 @@ class _FileParser(URLParser):
     FileParser objects are threadsafe. A factory function is used to cache
     FileParser instances, so for any one path only a single FileParser instance
     will exist.  The `_FileParser` class is the real class, and `FileParser` is
-    a factory that either returns an existant _FileParser object, or creates a
+    a factory that either returns an existent _FileParser object, or creates a
     new one if none exists.
 
     FileParser uses several settings from ``Application.config``, which are
